pub fn prepare_compaction(
entries: &[SessionEntry],
settings: &CompactionSettings,
) -> Option<CompactionPreparation>Expand description
Analyse the session branch and determine what should be compacted.
Returns None when the last entry is already a compaction (nothing new to do).