pub fn append_entry_to_file(path: &Path, entry: &SessionEntry) -> Result<()>Expand description
Append a single entry to the session file (one JSON line).
pub fn append_entry_to_file(path: &Path, entry: &SessionEntry) -> Result<()>Append a single entry to the session file (one JSON line).