pub struct BashExecution { /* private fields */ }Expand description
Bash execution component - renders a bash command with borders, spinner, and output.
Matches pi’s BashExecutionComponent design:
- Spacer (1 blank line) above top border
- Top/bottom borders in
bashModecolor (ordimfor !! commands) - Command header with
$prefix - Spinner while running (uses Loader component)
- Streaming output in muted color (no ANSI)
- Collapse/expand support showing FIRST N lines (preview truncation)
- Status line with exit code, duration, cancellation, truncation warnings
- Width-aware visual truncation for collapsed preview
Implementations
Sourceimpl BashExecution
impl BashExecution
pub fn new(command: impl Into<String>) -> Self
pub fn append_output(&mut self, line: impl Into<String>)
Sourcepub fn append_chunk(&mut self, chunk: &str)
pub fn append_chunk(&mut self, chunk: &str)
Append a chunk of output that may contain newlines. Handles splitting into lines similar to pi’s appendOutput (preserving incomplete last line).
pub fn set_complete(&mut self, exit_code: i32)
pub fn set_cancelled(&mut self)
pub fn set_error(&mut self, msg: impl Into<String>)
pub fn set_expanded(&mut self, expanded: bool)
pub fn set_exclude_from_context(&mut self, exclude: bool)
pub fn set_full_output_path(&mut self, path: impl Into<String>)
pub fn set_truncated(&mut self, truncated: bool)
Sourcepub fn set_duration_secs(&mut self, secs: f64)
pub fn set_duration_secs(&mut self, secs: f64)
Set the execution duration in seconds.
Sourcepub fn set_duration_from_content(&mut self, content: &str)
pub fn set_duration_from_content(&mut self, content: &str)
Parse and set duration from result content (format: [Xs] at end of string).
pub fn is_expanded(&self) -> bool
Sourcepub fn get_output(&self) -> String
pub fn get_output(&self) -> String
Get the raw output (for building messages sent to the LLM).
Sourcepub fn get_command(&self) -> String
pub fn get_command(&self) -> String
Get the command that was executed.