pub struct ModelsCallbacks {
pub on_change: Box<dyn Fn(Option<Vec<String>>)>,
pub on_persist: Box<dyn Fn(Option<Vec<String>>)>,
pub on_cancel: Box<dyn Fn()>,
}Fields
on_change: Box<dyn Fn(Option<Vec<String>>)>Called whenever the enabled model set or order changes (session-only, no persist).
on_persist: Box<dyn Fn(Option<Vec<String>>)>Called when user wants to persist current selection to settings.
on_cancel: Box<dyn Fn()>Called when user cancels.