pub fn read_credential(provider: &str) -> Result<Option<AuthCredential>>Expand description
Read a credential from auth.json. Returns None if the provider has no stored credential.
pub fn read_credential(provider: &str) -> Result<Option<AuthCredential>>Read a credential from auth.json. Returns None if the provider has no stored credential.