FindOperations

Trait FindOperations 

pub trait FindOperations: Send + Sync {
    // Required method
    fn exec<'life0, 'life1, 'life2, 'async_trait>(
        &'life0 self,
        command: &'life1 str,
        cwd: &'life2 Path,
    ) -> Pin<Box<dyn Future<Output = Result<ExecOutput>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait,
             'life2: 'async_trait;
}
Pluggable operations for the find tool (matching pi’s FindOperations). Override these to delegate command execution to remote systems.

Required Methods

fn exec<'life0, 'life1, 'life2, 'async_trait>( &'life0 self, command: &'life1 str, cwd: &'life2 Path, ) -> Pin<Box<dyn Future<Output = Result<ExecOutput>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait, 'life2: 'async_trait,

Execute a shell command in the given working directory. Returns stdout, stderr, and exit code.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors