pub async fn poll_device_code_flow<T>(
options: PollOptions<'_, T>,
) -> Result<T, String>Expand description
Poll the token endpoint until the user completes login or the flow fails.
pub async fn poll_device_code_flow<T>(
options: PollOptions<'_, T>,
) -> Result<T, String>Poll the token endpoint until the user completes login or the flow fails.