pub struct SlashCommand {
pub name: String,
pub description: Option<String>,
pub argument_hint: Option<String>,
pub argument_completions: Option<Vec<AutocompleteItem>>,
pub get_argument_completions: Option<Arc<dyn Fn(&str) -> Vec<AutocompleteItem> + Send + Sync>>,
}Expand description
A slash command definition.
Fields
name: Stringdescription: Option<String>argument_hint: Option<String>argument_completions: Option<Vec<AutocompleteItem>>Static argument completions (pi-compat: getArgumentCompletions).
When set, these are filtered by the typed prefix and shown.
When None and get_argument_completions is also None, file completion is used.
get_argument_completions: Option<Arc<dyn Fn(&str) -> Vec<AutocompleteItem> + Send + Sync>>Dynamic argument completions callback (pi-style getArgumentCompletions).
Called with the typed argument prefix, returns matching items.
Takes precedence over argument_completions when set.