Module component

Module component 

Structs

RenderCache
Cached render output.
RenderCacheKey
Key for render caching — components return this to indicate when cache is valid. Two renders with the same cache key produce identical output.

Traits

Component
Every renderable UI element.