pub struct RenderCacheKey {
pub width: usize,
pub expanded: bool,
pub state_hash: u64,
}Expand description
Key for render caching — components return this to indicate when cache is valid. Two renders with the same cache key produce identical output.
Fields
width: usizeViewport width.
expanded: boolWhether expanded (for collapsible components).
state_hash: u64Additional state hash (tool name, args hash, etc.).