Structs
- Dynamic
Lines - A component that wraps a
Vec<String>buffer that can be updated dynamically. Used for sections whose content changes each frame (pending text, status, etc.).
Vec<String> buffer that can be updated dynamically.
Used for sections whose content changes each frame (pending text, status, etc.).