pub struct MarkdownTheme {Show 16 fields
pub heading: StyleFn,
pub link: StyleFn,
pub link_url: StyleFn,
pub code: StyleFn,
pub code_block: StyleFn,
pub code_block_border: StyleFn,
pub quote: StyleFn,
pub quote_border: StyleFn,
pub hr: StyleFn,
pub list_bullet: StyleFn,
pub bold: StyleFn,
pub italic: StyleFn,
pub strikethrough: StyleFn,
pub underline: StyleFn,
pub highlight_code: Option<HighlightFn>,
pub code_block_indent: String,
}Expand description
Theme functions for markdown elements. Each function takes text and returns styled text with ANSI codes.
Fields
heading: StyleFnlink: StyleFnlink_url: StyleFncode: StyleFncode_block: StyleFncode_block_border: StyleFnquote: StyleFnquote_border: StyleFnhr: StyleFnlist_bullet: StyleFnbold: StyleFnitalic: StyleFnstrikethrough: StyleFnunderline: StyleFnhighlight_code: Option<HighlightFn>If set, used for syntax-highlighted code blocks.
code_block_indent: StringPrefix applied to each rendered code block line (default: " ").
Implementations
Sourceimpl MarkdownTheme
impl MarkdownTheme