Skip to main contentModule types
Source - AgentMessage
- A universal message type in the conversation.
- PendingMessageQueue
- A pending message queue with a configurable drain mode.
Used for steering (mid-stream) and follow-up (post-agent) message delivery.
- ToolCall
- A tool call requested by the assistant.
- Usage
- Token usage information for an assistant response.
- QueueMode
- How queued messages are drained from a pending message queue.
- Role
- Role of a message in the conversation.
- ToolExecutionMode
- Whether the agent executes tool calls in parallel (default) or sequentially.