OAuth device code flow poller — matching pi’s pollOAuthDeviceCodeFlow.
Polls the token endpoint at the configured interval until the user completes the login in their browser, the flow times out, or is cancelled.
Structs
- Poll
Options - Options for the device code poller.
Enums
- Poll
Status - Result from a single poll attempt.
Functions
- poll_
device_ code_ flow - Poll the token endpoint until the user completes login or the flow fails.
Type Aliases
- PollFn
- Async poll function type for device code flow.