pub struct WordNavigationOptions<'a> {
pub segment: Option<&'a dyn Fn(&str) -> Vec<WordSegment>>,
pub is_atomic_segment: Option<&'a dyn Fn(&str) -> bool>,
}Expand description
Options for word navigation functions (matching pi’s WordNavigationOptions).
Fields
segment: Option<&'a dyn Fn(&str) -> Vec<WordSegment>>Custom segmenter returning word segments for the given text.
When omitted, uses grapheme-based segmentation with is_word_char heuristic.
is_atomic_segment: Option<&'a dyn Fn(&str) -> bool>Predicate identifying atomic segments that should be treated as single units. When provided, segments matching this predicate are skipped atomically.